#[repr(C)]pub struct NV_DISPLAY_DRIVER_MEMORY_INFO_V1 {
pub version: u32,
pub dedicatedVideoMemory: u32,
pub availableDedicatedVideoMemory: u32,
pub systemVideoMemory: u32,
pub sharedSystemMemory: u32,
}Expand description
Used in NvAPI_GPU_GetMemoryInfo().
Fields
version: u32Version info
dedicatedVideoMemory: u32Size(in kb) of the physical framebuffer.
availableDedicatedVideoMemory: u32Size(in kb) of the available physical framebuffer for allocating video memory surfaces.
systemVideoMemory: u32Size(in kb) of system memory the driver allocates at load time.
Size(in kb) of shared system memory that driver is allowed to commit for surfaces across all allocations.
Implementations