#[repr(C)]pub struct NV_GPU_THERMAL_SETTINGS_SENSOR {
pub controller: NV_THERMAL_CONTROLLER,
pub defaultMinTemp: i32,
pub defaultMaxTemp: i32,
pub currentTemp: i32,
pub target: NV_THERMAL_TARGET,
}Expand description
Anonymous struct in NV_GPU_THERMAL_SETTINGS
Fields
controller: NV_THERMAL_CONTROLLERinternal, ADM1032, MAX6649…
defaultMinTemp: i32The min default temperature value of the thermal sensor in degree Celsius
defaultMaxTemp: i32The max default temperature value of the thermal sensor in degree Celsius
currentTemp: i32The current temperature value of the thermal sensor in degree Celsius
target: NV_THERMAL_TARGETThermal sensor targeted @ GPU, memory, chipset, powersupply, Visual Computing Device, etc.
Implementations