Status

Enum Status 

#[repr(i32)]
pub enum Status {
Show 134 variants Ok = 0, Error = -1, LibraryNotFound = -2, NoImplementation = -3, ApiNotInitialized = -4, InvalidArgument = -5, NvidiaDeviceNotFound = -6, EndEnumeration = -7, InvalidHandle = -8, IncompatibleStructVersion = -9, HandleInvalidated = -10, OpenglContextNotCurrent = -11, InvalidPointer = -14, NoGlExpert = -12, InstrumentationDisabled = -13, NoGlNsight = -15, ExpectedLogicalGpuHandle = -100, ExpectedPhysicalGpuHandle = -101, ExpectedDisplayHandle = -102, InvalidCombination = -103, NotSupported = -104, PortidNotFound = -105, ExpectedUnattachedDisplayHandle = -106, InvalidPerfLevel = -107, DeviceBusy = -108, NvPersistFileNotFound = -109, PersistDataNotFound = -110, ExpectedTvDisplay = -111, ExpectedTvDisplayOnDconnector = -112, NoActiveSliTopology = -113, SliRenderingModeNotallowed = -114, ExpectedDigitalFlatPanel = -115, ArgumentExceedMaxSize = -116, DeviceSwitchingNotAllowed = -117, TestingClocksNotSupported = -118, UnknownUnderscanConfig = -119, TimeoutReconfiguringGpuTopo = -120, DataNotFound = -121, ExpectedAnalogDisplay = -122, NoVidlink = -123, RequiresReboot = -124, InvalidHybridMode = -125, MixedTargetTypes = -126, Syswow64NotSupported = -127, ImplicitSetGpuTopologyChangeNotAllowed = -128, RequestUserToCloseNonMigratableApps = -129, OutOfMemory = -130, WasStillDrawing = -131, FileNotFound = -132, TooManyUniqueStateObjects = -133, InvalidCall = -134, D3d101LibraryNotFound = -135, FunctionNotFound = -136, InvalidUserPrivilege = -137, ExpectedNonPrimaryDisplayHandle = -138, ExpectedComputeGpuHandle = -139, StereoNotInitialized = -140, StereoRegistryAccessFailed = -141, StereoRegistryProfileTypeNotSupported = -142, StereoRegistryValueNotSupported = -143, StereoNotEnabled = -144, StereoNotTurnedOn = -145, StereoInvalidDeviceInterface = -146, StereoParameterOutOfRange = -147, StereoFrustumAdjustModeNotSupported = -148, TopoNotPossible = -149, ModeChangeFailed = -150, D3d11LibraryNotFound = -151, InvalidAddress = -152, StringTooSmall = -153, MatchingDeviceNotFound = -154, DriverRunning = -155, DriverNotrunning = -156, ErrorDriverReloadRequired = -157, SetNotAllowed = -158, AdvancedDisplayTopologyRequired = -159, SettingNotFound = -160, SettingSizeTooLarge = -161, TooManySettingsInProfile = -162, ProfileNotFound = -163, ProfileNameInUse = -164, ProfileNameEmpty = -165, ExecutableNotFound = -166, ExecutableAlreadyInUse = -167, DatatypeMismatch = -168, ProfileRemoved = -169, UnregisteredResource = -170, IdOutOfRange = -171, DisplayconfigValidationFailed = -172, DpmstChanged = -173, InsufficientBuffer = -174, AccessDenied = -175, MosaicNotActive = -176, ShareResourceRelocated = -177, RequestUserToDisableDwm = -178, D3dDeviceLost = -179, InvalidConfiguration = -180, StereoHandshakeNotDone = -181, ExecutablePathIsAmbiguous = -182, DefaultStereoProfileIsNotDefined = -183, DefaultStereoProfileDoesNotExist = -184, ClusterAlreadyExists = -185, DpmstDisplayIdExpected = -186, InvalidDisplayId = -187, StreamIsOutOfSync = -188, IncompatibleAudioDriver = -189, ValueAlreadySet = -190, Timeout = -191, GpuWorkstationFeatureIncomplete = -192, StereoInitActivationNotDone = -193, SyncNotActive = -194, SyncMasterNotFound = -195, InvalidSyncTopology = -196, EcidSignAlgoUnsupported = -197, EcidKeyVerificationFailed = -198, FirmwareOutOfDate = -199, FirmwareRevisionNotSupported = -200, LicenseCallerAuthenticationFailed = -201, D3dDeviceNotRegistered = -202, ResourceNotAcquired = -203, TimingNotSupported = -204, HdcpEncryptionFailed = -205, PclkLimitationFailed = -206, NoConnectorFound = -207, HdcpDisabled = -208, ApiInUse = -209, NvidiaDisplayNotFound = -210, PrivSecViolation = -211, IncorrectVendor = -212, DisplayInUse = -213, UnsupportedConfigNonHdcpHmd = -214, MaxDisplayLimitReached = -215, InvalidDirectModeDisplay = -216, GpuInDebugMode = -217,
}
NvAPI Status Values

All NvAPI functions return one of these codes.

Variants



Ok = 0

Success. Request is completed.



Error = -1

Generic error



LibraryNotFound = -2

NVAPI support library cannot be loaded.



NoImplementation = -3

not implemented in current driver installation



ApiNotInitialized = -4

NvAPI_Initialize has not been called (successfully)



InvalidArgument = -5

The argument/parameter value is not valid or NULL.



NvidiaDeviceNotFound = -6

No NVIDIA display driver, or NVIDIA GPU driving a display, was found.



EndEnumeration = -7

No more items to enumerate



InvalidHandle = -8

Invalid handle



IncompatibleStructVersion = -9

An argument’s structure version is not supported



HandleInvalidated = -10

The handle is no longer valid (likely due to GPU or display re-configuration)



OpenglContextNotCurrent = -11

No NVIDIA OpenGL context is current (but needs to be)



InvalidPointer = -14

An invalid pointer, usually NULL, was passed as a parameter



NoGlExpert = -12

OpenGL Expert is not supported by the current drivers



InstrumentationDisabled = -13

OpenGL Expert is supported, but driver instrumentation is currently disabled



NoGlNsight = -15

OpenGL does not support Nsight



ExpectedLogicalGpuHandle = -100

Expected a logical GPU handle for one or more parameters



ExpectedPhysicalGpuHandle = -101

Expected a physical GPU handle for one or more parameters



ExpectedDisplayHandle = -102

Expected an NV display handle for one or more parameters



InvalidCombination = -103

The combination of parameters is not valid.



NotSupported = -104

Requested feature is not supported in the selected GPU



PortidNotFound = -105

No port ID was found for the I2C transaction



ExpectedUnattachedDisplayHandle = -106

Expected an unattached display handle as one of the input parameters.



InvalidPerfLevel = -107

Invalid perf level



DeviceBusy = -108

Device is busy; request not fulfilled



NvPersistFileNotFound = -109

NV persist file is not found



PersistDataNotFound = -110

NV persist data is not found



ExpectedTvDisplay = -111

Expected a TV output display



ExpectedTvDisplayOnDconnector = -112

Expected a TV output on the D Connector - HDTV_EIAJ4120.



NoActiveSliTopology = -113

SLI is not active on this device.



SliRenderingModeNotallowed = -114

Setup of SLI rendering mode is not possible right now.



ExpectedDigitalFlatPanel = -115

Expected a digital flat panel.



ArgumentExceedMaxSize = -116

Argument exceeds the expected size.



DeviceSwitchingNotAllowed = -117

Inhibit is ON due to one of the flags in NV_GPU_DISPLAY_CHANGE_INHIBIT or SLI active.



TestingClocksNotSupported = -118

Testing of clocks is not supported.



UnknownUnderscanConfig = -119

The specified underscan config is from an unknown source (e.g. INF)



TimeoutReconfiguringGpuTopo = -120

Timeout while reconfiguring GPUs



DataNotFound = -121

Requested data was not found



ExpectedAnalogDisplay = -122

Expected an analog display

No SLI video bridge is present



RequiresReboot = -124

NVAPI requires a reboot for the settings to take effect



InvalidHybridMode = -125

The function is not supported with the current Hybrid mode.



MixedTargetTypes = -126

The target types are not all the same



Syswow64NotSupported = -127

The function is not supported from 32-bit on a 64-bit system.



ImplicitSetGpuTopologyChangeNotAllowed = -128

There is no implicit GPU topology active. Use NVAPI_SetHybridMode to change topology.



RequestUserToCloseNonMigratableApps = -129

Prompt the user to close all non-migratable applications.



OutOfMemory = -130

Could not allocate sufficient memory to complete the call.



WasStillDrawing = -131

The previous operation that is transferring information to or from this surface is incomplete.



FileNotFound = -132

The file was not found.



TooManyUniqueStateObjects = -133

There are too many unique instances of a particular type of state object.



InvalidCall = -134

The method call is invalid. For example, a method’s parameter may not be a valid pointer.



D3d101LibraryNotFound = -135

d3d10_1.dll cannot be loaded.



FunctionNotFound = -136

Couldn’t find the function in the loaded DLL.



InvalidUserPrivilege = -137

Current User is not Admin.



ExpectedNonPrimaryDisplayHandle = -138

The handle corresponds to GDIPrimary.



ExpectedComputeGpuHandle = -139

Setting Physx GPU requires that the GPU is compute-capable.



StereoNotInitialized = -140

The Stereo part of NVAPI failed to initialize completely. Check if the stereo driver is installed.



StereoRegistryAccessFailed = -141

Access to stereo-related registry keys or values has failed.



StereoRegistryProfileTypeNotSupported = -142

The given registry profile type is not supported.



StereoRegistryValueNotSupported = -143

The given registry value is not supported.



StereoNotEnabled = -144

Stereo is not enabled and the function needed it to execute completely.



StereoNotTurnedOn = -145

Stereo is not turned on and the function needed it to execute completely.



StereoInvalidDeviceInterface = -146

Invalid device interface.



StereoParameterOutOfRange = -147

Separation percentage or JPEG image capture quality is out of [0-100] range.



StereoFrustumAdjustModeNotSupported = -148

The given frustum adjust mode is not supported.



TopoNotPossible = -149

The mosaic topology is not possible given the current state of the hardware.



ModeChangeFailed = -150

An attempt to do a display resolution mode change has failed.



D3d11LibraryNotFound = -151

d3d11.dll/d3d11_beta.dll cannot be loaded.



InvalidAddress = -152

Address is outside of valid range.



StringTooSmall = -153

The pre-allocated string is too small to hold the result.



MatchingDeviceNotFound = -154

The input does not match any of the available devices.



DriverRunning = -155

Driver is running.



DriverNotrunning = -156

Driver is not running.



ErrorDriverReloadRequired = -157

A driver reload is required to apply these settings.



SetNotAllowed = -158

Intended setting is not allowed.



AdvancedDisplayTopologyRequired = -159

Information can’t be returned due to “advanced display topology”.



SettingNotFound = -160

Setting is not found.



SettingSizeTooLarge = -161

Setting size is too large.



TooManySettingsInProfile = -162

There are too many settings for a profile.



ProfileNotFound = -163

Profile is not found.



ProfileNameInUse = -164

Profile name is duplicated.



ProfileNameEmpty = -165

Profile name is empty.



ExecutableNotFound = -166

Application not found in the Profile.



ExecutableAlreadyInUse = -167

Application already exists in the other profile.



DatatypeMismatch = -168

Data Type mismatch



ProfileRemoved = -169

The profile passed as parameter has been removed and is no longer valid.



UnregisteredResource = -170

An unregistered resource was passed as a parameter.



IdOutOfRange = -171

The DisplayId corresponds to a display which is not within the normal outputId range.



DisplayconfigValidationFailed = -172

Display topology is not valid so the driver cannot do a mode set on this configuration.



DpmstChanged = -173

Display Port Multi-Stream topology has been changed.



InsufficientBuffer = -174

Input buffer is insufficient to hold the contents.



AccessDenied = -175

No access to the caller.



MosaicNotActive = -176

The requested action cannot be performed without Mosaic being enabled.



ShareResourceRelocated = -177

The surface is relocated away from video memory.



RequestUserToDisableDwm = -178

The user should disable DWM before calling NvAPI.



D3dDeviceLost = -179

D3D device status is D3DERR_DEVICELOST or D3DERR_DEVICENOTRESET - the user has to reset the device.



InvalidConfiguration = -180

The requested action cannot be performed in the current state.



StereoHandshakeNotDone = -181

Call failed as stereo handshake not completed.



ExecutablePathIsAmbiguous = -182

The path provided was too short to determine the correct NVDRS_APPLICATION



DefaultStereoProfileIsNotDefined = -183

Default stereo profile is not currently defined



DefaultStereoProfileDoesNotExist = -184

Default stereo profile does not exist



ClusterAlreadyExists = -185

A cluster is already defined with the given configuration.



DpmstDisplayIdExpected = -186

The input display id is not that of a multi stream enabled connector or a display device in a multi stream topology



InvalidDisplayId = -187

The input display id is not valid or the monitor associated to it does not support the current operation



StreamIsOutOfSync = -188

While playing secure audio stream, stream goes out of sync



IncompatibleAudioDriver = -189

Older audio driver version than required



ValueAlreadySet = -190

Value already set, setting again not allowed.



Timeout = -191

Requested operation timed out



GpuWorkstationFeatureIncomplete = -192

The requested workstation feature set has incomplete driver internal allocation resources



StereoInitActivationNotDone = -193

Call failed because InitActivation was not called.



SyncNotActive = -194

The requested action cannot be performed without Sync being enabled.



SyncMasterNotFound = -195

The requested action cannot be performed without Sync Master being enabled.



InvalidSyncTopology = -196

Invalid displays passed in the NV_GSYNC_DISPLAY pointer.



EcidSignAlgoUnsupported = -197

The specified signing algorithm is not supported. Either an incorrect value was entered or the current installed driver/hardware does not support the input value.



EcidKeyVerificationFailed = -198

The encrypted public key verification has failed.



FirmwareOutOfDate = -199

The device’s firmware is out of date.



FirmwareRevisionNotSupported = -200

The device’s firmware is not supported.



LicenseCallerAuthenticationFailed = -201

The caller is not authorized to modify the License.



D3dDeviceNotRegistered = -202

The user tried to use a deferred context without registering the device first



ResourceNotAcquired = -203

Head or SourceId was not reserved for the VR Display before doing the Modeset.



TimingNotSupported = -204

Provided timing is not supported.



HdcpEncryptionFailed = -205

HDCP Encryption Failed for the device. Would be applicable when the device is HDCP Capable.



PclkLimitationFailed = -206

Provided mode is over sink device pclk limitation.



NoConnectorFound = -207

No connector on GPU found.



HdcpDisabled = -208

When a non-HDCP capable HMD is connected, we would inform user by this code.



ApiInUse = -209

Atleast an API is still being called



NvidiaDisplayNotFound = -210

No display found on Nvidia GPU(s).



PrivSecViolation = -211

Priv security violation, improper access to a secured register.



IncorrectVendor = -212

NVAPI cannot be called by this vendor



DisplayInUse = -213

DirectMode Display is already in use



UnsupportedConfigNonHdcpHmd = -214

The Config is having Non-NVidia GPU with Non-HDCP HMD connected



MaxDisplayLimitReached = -215

GPU’s Max Display Limit has Reached



InvalidDirectModeDisplay = -216

DirectMode not Enabled on the Display



GpuInDebugMode = -217

GPU is in debug mode, OC is NOT allowed.

Implementations

Source

impl Status

pub fn from_raw(raw: NvAPI_Status) -> Result<Self, ArgumentRangeError>

pub fn raw(&self) -> NvAPI_Status

pub fn values() -> Cloned<Iter<'static, Self>>